import os


class Config:
    
    db_name = None
    chrome_data = None
    log_path = None

    def __init__(self):
        self.get_path()

    def get_path(self):
        home_path = os.environ["HOME"]
        if not os.path.exists(f"{home_path}/.chrome-spider"):
            os.mkdir(f"{home_path}/.chrome-spider")
        if not os.path.exists(f"{home_path}/.chrome-spider/logs/"):
            os.mkdir(f"{home_path}/.chrome-spider/logs/")

        self.db_name = f"{home_path}/.chrome-spider/spider.db"
        self.chrome_data = f"{home_path}/.chrome-spider/chrome-data"
        self.log_path = f"{home_path}/.chrome-spider/logs/logging.log"


config = Config()



import logging
from chrome_spider.common.config import config

def get_logger(level="INFO"):
    logfile = config.logfile
    # 基本配置
    logger = logging.getLogger(__name__)
    logger.propagate = False
    logger.setLevel(level)
    formatter = logging.Formatter("%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s")
    # 设置文件句柄 管理输出到日志的格式
    file_handler = logging.FileHandler(logfile, 'a+', encoding='utf-8')
    file_handler.setLevel(level)
    file_handler.setFormatter(formatter)
    # 设置stream句柄 管理输出到控制台的格式
    stream_handler = logging.StreamHandler()
    stream_handler.setLevel(level)
    stream_handler.setFormatter(formatter)
    # logger.handlers.clear()
    # 添加句柄到logger
    logger.addHandler(file_handler)
    logger.addHandler(stream_handler)
    # file_handler.close()
    # stream_handler.close()
    return logger


import sqlite3
import os
from chrome_spider.common.config import config

create_table_account = '''
create table account(
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    name varchar(200),
    phone_number varchar(200),
    password varchar(200),
    cookie varchar(1000),
    host varchar(10)
);
'''


# mkdir ~/.flow-track
class DB():
    def __init__(self):
        db_name = config.db_name
        self.conn = sqlite3.connect(db_name)
        self.cursor = self.conn.cursor()

    def __enter__(self):
        return self.cursor

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.conn.commit()
        self.cursor.close()
        self.conn.close()

def init_table():
    with DB() as cursor:
        cursor.execute(create_table_account)
        

        
if __name__ == "__main__":
    with DB() as cursor:
        init_table()
